---

name: Documentation Improvement
about: Report wrong or missing documentation
title: "DOC:"
labels: "documentation"

---

#### Location of the documentation

Provide the location of the documentation, e.g. an URL of the documentation.

**Note**: You can check the latest versions of the docs on `main`
[here](https://pytask-dev.readthedocs.io/en/latest).

#### Documentation problem

Provide a description of what documentation you believe needs to be fixed/improved.

#### Suggested fix for documentation

Explain the suggested fix and **why** it's better than the existing documentation.
